@@ -11,7 +11,7 @@ our @ISA = qw(Exporter);
 our %EXPORT_TAGS = ( 'all' => [ qw/ OK WARNING CRITICAL UNKNOWN DEPENDENT / ] );
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use constant OK         => 0;
 use constant WARNING    => 1;
@@ -38,7 +38,7 @@ Net::NSCAng::Client - Submit host and service monitoring results using the NSCA-
 =head1 DESCRIPTION
 
 Net::NSCAng::Client provides a means of sending host or service check results
-to an L<NCSA-ng|http://www.nsca-ng.org/> server. It is derived from the Python
+to an L<NSCA-ng|http://www.nsca-ng.org/> server. It is derived from the Python
 code written by Alexander Golovko <alexandro@onsec.ru> but with a more perlish
 interface.
 
